@@ -1,7 +1,6 @@
 package Net::OAuth::LP;
 
-use strictures 1;
-use Moo::Role;
+use Moo;
 use Method::Signatures;
 
 use Browser::Open qw[open_browser];
@@ -11,7 +10,7 @@ use LWP::UserAgent;
 use Net::OAuth;
 $Net::OAuth::PROTOCOL_VERSION = Net::OAuth::PROTOCOL_VERSION_1_0;
 
-our $VERSION = '0.0010'; # VERSION
+# VERSION
 
 has consumer_key => (
     is      => 'rw',
@@ -93,9 +92,12 @@ has api_url => (
 has staging => (
     is      => 'rw',
     isa     => method {},
-    default => method { 0 },
+    default => 0,
 );
 
+###########################################################################
+# Protected
+###########################################################################
 method _nonce {
     my @a = ('A' .. 'Z', 'a' .. 'z', 0 .. 9);
     my $nonce = '';
@@ -106,6 +108,57 @@ method _nonce {
     $nonce;
 }
 
+###########################################################################
+# Public
+###########################################################################
+method login_with_creds {
+    my $ua      = LWP::UserAgent->new();
+    my $request = Net::OAuth->request('consumer')->new(
+        consumer_key     => $self->consumer_key,
+        consumer_secret  => '',
+        request_url      => $self->request_token_url,
+        request_method   => 'POST',
+        signature_method => 'PLAINTEXT',
+        timestamp        => time,
+        nonce            => $self->_nonce,
+    );
+
+    $request->sign;
+    my $res =
+      $ua->request(POST $request->to_url, Content => $request->to_post_body);
+
+    die "Failed to get response" unless $res->is_success;
+    my $response =
+      Net::OAuth->response('request token')->from_post_body($res->content);
+    my $_token        = $response->token;
+    my $_token_secret = $response->token_secret;
+    open_browser($self->authorize_token_url . "?oauth_token=" . $_token);
+
+    print "Pulling authorization credentials.\n";
+
+    $request = Net::OAuth->request('access token')->new(
+        consumer_key     => $self->consumer_key,
+        consumer_secret  => '',
+        token            => $_token,
+        token_secret     => $_token_secret,
+        request_url      => $self->access_token_url,
+        request_method   => 'POST',
+        signature_method => 'PLAINTEXT',
+        timestamp        => time,
+        nonce            => $self->_nonce
+    );
+
+    $request->sign;
+
+    $res =
+      $ua->request(POST $request->to_url, Content => $request->to_post_body);
+    die "Failed to get response" unless $res->is_success;
+    $response =
+      Net::OAuth->response('access token')->from_post_body($res->content);
+    $self->access_token($response->token);
+    $self->access_token_secret($response->token_secret);
+}
+
 1;
 
 =head1 NAME
@@ -116,27 +169,45 @@ Net::OAuth::LP - Launchpad.net OAuth 1.0
 
 OAuth 1.0a authorization and client for Launchpad.net
 
+    use Net::OAuth::LP;
+
+    my $lp = Net::OAuth::LP->new;
+    $lp->consumer_key('my-lp-app');
+
+    # Authorize yourself
+    $lp->login_with_creds;
+
 =head1 ATTRIBUTES
 
 L<Net::OAuth::LP> implements the following attributes:
 
-=head2 B<consumer_key>
+=head2 C<consumer_key>
 
 Holds the string that identifies your application.
 
     $lp->consumer_key('my-app-name');
 
-=head2 B<token>
+=head2 C<token>
 
 Token received from authorized request
 
-=head2 B<token_secret>
+=head2 C<token_secret>
 
 Token secret received from authorized request
 
+=head1 METHODS
+
+=head2 C<new>
+
+    my $lp = Net::OAuth::LP->new;
+
+=head2 C<login_with_creds>
+
+    $lp->login_with_creds;
+
 =head1 AUTHOR
 
-Adam 'battlemidget' Stokes, C<< <adamjs at cpan.org> >>
+Adam 'battlemidget' Stokes, C<< <adam.stokes at ubuntu.com> >>
 
 =head1 BUGS
 
@@ -154,14 +225,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Net::OAuth::LP
 
-=head1 SEE ALSO
-
-=over 4
-
-=item * L<https://launchpad.net/launchpadlib>, "Python implementation"
-
-=back
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2013 Adam Stokes.
